@@ -20,8 +20,10 @@ from prometheus_client import CollectorRegistry, generate_latest, multiprocess
 # from prometheus_client
 from werkzeug.middleware.dispatcher import DispatcherMiddleware
 
+from .fastapi_metrics_redirect import MetricsRedirect
 from ..utils.singleton import SingletonMeta
 from ..utils.bcolor import Bcolors
+
 from .config import _DEFAULT_BUCKETS, _DEFAULT_LABELS, NAMESPACE, SERVICENAME
 
 
@@ -327,6 +329,7 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
 
     def add_fastapi_middleware(self):
         # TODO look into this later
+        self.app.add_middleware(MetricsRedirect)
         self.app.mount("/metrics", WSGIMiddleware(make_wsgi_app()))
 
         # NOTE: loop through all endpoint and get path_format
